package com.lilosoft.api.controller;

import cn.hutool.core.util.IdUtil;
import cn.hutool.json.JSONUtil;
import com.lilosoft.api.api.RobotApi;
import com.lilosoft.api.bean.RobotCaseRecord;
import com.lilosoft.api.service.ApplyService;
import com.lilosoft.core.utils.ObjectUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.jms.annotation.JmsListener;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.HashMap;

@Service
public class MqConsumer {

    /**
     * 日志对象
     */
    public Logger logger = LoggerFactory.getLogger(getClass());

    @Autowired
    private ApplyService applyService;

    @Autowired
    private RobotApi robotApi;

    @Value("${api.mq}")
    private String mq;

    @JmsListener(destination = "${api.mq}", containerFactory = "jmsListenerContainerQueue")
    public void receiveMsg(HashMap<String, String> text) {
        RobotCaseRecord caseRecord = new RobotCaseRecord();
        caseRecord.setId(IdUtil.simpleUUID());
        caseRecord.setContent(text.get("content"));
        caseRecord.setAreaCode(mq);
        caseRecord.setSendFlag("0");
        caseRecord.setUpdateTime(new Date());
        try {
            robotApi.saveRecord(caseRecord);
            HashMap<String, Object> entries = JSONUtil.toBean(text.get("content"), HashMap.class);
            String apply = applyService.webApply(entries);
            if(ObjectUtils.isEmpty(apply)){
                caseRecord.setSendFlag("2");
                caseRecord.setMsg("success");
            } else {
                caseRecord.setSendFlag("1");
                caseRecord.setMsg(apply);
            }
            robotApi.saveRecord(caseRecord);
        } catch (Exception e) {
            caseRecord.setSendFlag("1");
            caseRecord.setMsg(e.getMessage());
            robotApi.saveRecord(caseRecord);
            logger.error(e.getMessage());
        }


    }

}
